@@ -31,6 +31,15 @@
 #include <boost/asio/buffers_iterator.hpp>
 #include <boost/asio/io_context.hpp>
 #include <boost/asio/streambuf.hpp>
+#if BOOST_VERSION >= 108600
+#include <boost/process/v1/async.hpp>
+#include <boost/process/v1/child.hpp>
+#include <boost/process/v1/env.hpp>
+#include <boost/process/v1/environment.hpp>
+#include <boost/process/v1/group.hpp>
+#include <boost/process/v1/io.hpp>
+#include <boost/process/v1/search_path.hpp>
+#else
 #include <boost/process/async.hpp>
 #include <boost/process/child.hpp>
 #include <boost/process/env.hpp>
@@ -39,6 +48,7 @@
 #include <boost/process/io.hpp>
 #include <boost/process/search_path.hpp>
 #endif
+#endif
 
 #ifdef PLATFORM_WINDOWS
 #include <windows.h>
